# Author:: Toshiro Sugii
# Copyright:: Copyright (c) 2016 Toshiro Sugii
# License::   Distributes under the same terms as Ruby
require 'erubis'

module Jaspion
  module Miya
    # Represents a result file template that can be manipulated
    class Template
      # Object object that template is related to
      attr_accessor :object

      # Template file path
      attr_accessor :file_path

      class << self
        # Returns all available classes
        #
        # @return [String] Directory path of /template
        def dir_path
          File.expand_path(File.join(__FILE__, '..', '..', '..', 'templates'))
        end
      end

      # Initializes an Template object
      #
      # @param object [Object] Object object related to this template
      #
      # @param path [String] Source - template path
      # => If path == nil, it tries to figure out the path by Object class name
      def initialize(object = nil, path = nil)
        @object    = object
        @file_path = (path || default_file_path)
      end

      def default_file_path
        unless object.nil?
          path_components = object.class.name.split('::')[1..-1]
          path_components[0] = self.class.dir_path
          return File.join(*path_components.map(&:downcase)) + '.erb'
        end
      end

      # Returns the parsed template code using ERUBIS
      # The template file should be in /template directory
      #
      # @return [String] Parsed code
      def source_code
        return nil if @file_path.nil? || !File.file?(@file_path)
        Erubis::Eruby.new(File.read(@file_path)).evaluate(object)
      end

      def save(path)
      end
    end
  end
end
